@@ -1,7 +1,7 @@
 """
 Type annotations for cloudcontrol service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudcontrol/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudcontrol/literals/)
 
 Usage::
 
@@ -24,8 +24,11 @@ __all__ = (
     "OperationStatusType",
     "OperationType",
     "ResourceRequestSuccessWaiterName",
+    "CloudControlApiServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "WaiterName",
+    "RegionName",
 )
 
 
@@ -51,6 +54,7 @@ OperationStatusType = Literal[
 ]
 OperationType = Literal["CREATE", "DELETE", "UPDATE"]
 ResourceRequestSuccessWaiterName = Literal["resource_request_success"]
+CloudControlApiServiceName = Literal["cloudcontrol"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -82,6 +86,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -168,6 +173,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -204,6 +210,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -352,4 +359,40 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 WaiterName = Literal["resource_request_success"]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ap-southeast-3",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
